@@ -21,7 +21,7 @@
 
 set -euo pipefail
 
-echo "1..$((25 + ${extra_admin_tests:-0}))"
+echo "1..$((26 + ${extra_admin_tests:-0}))"
 
 function validate_bootloader() {
     cd ${test_tmpdir};
@@ -60,7 +60,7 @@ validate_bootloader
 echo "ok deploy command"
 
 ${CMD_PREFIX} ostree admin --print-current-dir > curdir
-assert_file_has_content curdir ^`pwd`/sysroot/ostree/deploy/testos/deploy/${rev}.0$
+assert_file_has_content curdir ^`pwd`/sysroot/ostree/deploy/testos/deploy/${rev}\.0$
 
 echo "ok --print-current-dir"
 
@@ -239,7 +239,7 @@ cp ${originfile} saved-origin
 ${CMD_PREFIX} ostree admin set-origin --index=0 bacon --set=gpg-verify=false http://tasty.com
 assert_file_has_content "${originfile}" "bacon:testos/buildmaster/x86_64-runtime"
 ${CMD_PREFIX} ostree --repo=sysroot/ostree/repo remote list -u > remotes.txt
-assert_file_has_content remotes.txt 'bacon.*http://tasty.com'
+assert_file_has_content remotes.txt 'bacon.*http://tasty\.com'
 cp saved-origin ${originfile}
 validate_bootloader
 
@@ -280,6 +280,16 @@ validate_bootloader
 
 echo "ok upgrade with multiple kernel args"
 
+os_repository_new_commit
+${CMD_PREFIX} ostree admin upgrade --os=testos
+assert_file_has_content sysroot/boot/loader/entries/ostree-4-testos.conf "^title TestOS 42 ${version} (ostree:testos)$"
+os_repository_new_commit 0 0 testos/buildmaster/x86_64-runtime 42
+${CMD_PREFIX} ostree admin upgrade --os=testos
+assert_file_has_content sysroot/boot/loader/entries/ostree-4-testos.conf "^title TestOS 42 (ostree:testos)$"
+
+echo "ok no duplicate version strings in title"
+
+
 # Test upgrade with and without --override-commit
 # See https://github.com/GNOME/ostree/pull/147
 ${CMD_PREFIX} ostree pull --repo=sysroot/ostree/repo --commit-metadata-only --depth=-1 testos:testos/buildmaster/x86_64-runtime
